@@ -4,11 +4,14 @@ import platform
 import subprocess
 import time
 
+from configparser import RawConfigParser
+from io import StringIO
+from urllib.parse import urlsplit
+
 from botocore.utils import parse_timestamp
 
 from tests import CLIRunner, AWSRequest, AWSResponse
 from awscli.testutils import unittest, FileCreator, mock
-from awscli.compat import urlparse, StringIO, RawConfigParser
 from awscli.customizations.codeartifact.login import CodeArtifactLogin
 
 
@@ -40,7 +43,7 @@ class TestCodeArtifactLogin(unittest.TestCase):
         self.pypi_rc_path_mock = self.pypi_rc_path_patch.start()
         self.pypi_rc_path_mock.return_value = self.test_pypi_rc_path
 
-        self.subprocess_patch = mock.patch('subprocess.check_call')
+        self.subprocess_patch = mock.patch('subprocess.run')
         self.subprocess_mock = self.subprocess_patch.start()
         self.subprocess_check_output_patch = mock.patch(
             'subprocess.check_output'
@@ -143,7 +146,7 @@ class TestCodeArtifactLogin(unittest.TestCase):
         npm_cmd = 'npm.cmd' \
             if platform.system().lower() == 'windows' else 'npm'
 
-        repo_uri = urlparse.urlsplit(self.endpoint)
+        repo_uri = urlsplit(self.endpoint)
         always_auth_config = '//{}{}:always-auth'.format(
             repo_uri.netloc, repo_uri.path
         )
@@ -169,7 +172,7 @@ class TestCodeArtifactLogin(unittest.TestCase):
 
     def _get_pip_commands(self):
         pip_index_url_fmt = '{scheme}://aws:{auth_token}@{netloc}{path}simple/'
-        repo_uri = urlparse.urlsplit(self.endpoint)
+        repo_uri = urlsplit(self.endpoint)
         pip_index_url = pip_index_url_fmt.format(
             scheme=repo_uri.scheme,
             auth_token=self.auth_token,
@@ -218,7 +221,7 @@ password: {auth_token}'''
             pypi_rc.set('codeartifact', 'username', 'aws')
             pypi_rc.set('codeartifact', 'password', self.auth_token)
         else:
-            pypi_rc.readfp(StringIO(default_pypi_rc))
+            pypi_rc.read_string(default_pypi_rc)
 
         pypi_rc_stream = StringIO()
         pypi_rc.write(pypi_rc_stream)
@@ -274,8 +277,8 @@ password: {auth_token}'''
         expected_calls = [
             mock.call(
                 command,
-                stdout=subprocess.PIPE,
-                stderr=subprocess.PIPE,
+                capture_output=True,
+                check=True
             ) for command in commands
         ]
         self.subprocess_mock.assert_has_calls(
@@ -302,7 +305,7 @@ password: {auth_token}'''
         self, pypi_rc_str, server, repo_url=None, username=None, password=None
     ):
         pypi_rc = RawConfigParser()
-        pypi_rc.readfp(StringIO(pypi_rc_str))
+        pypi_rc.read_string(pypi_rc_str)
 
         self.assertIn('distutils', pypi_rc.sections())
         self.assertIn('index-servers', pypi_rc.options('distutils'))
@@ -572,6 +575,34 @@ password: {auth_token}'''
             result.stdout
         )
 
+    _NUGET_SOURCES_LIST_RESPONSE_WITH_EXTRA_NON_LIST_TEXT = b"""\
+Welcome to dotnet 2.0!
+
+Registered Sources:
+  1. Source Name 1 [Enabled]
+     https://source1.com/index.json
+  2. ati-nugetserver [Disabled]
+     http://atinugetserver-env.elasticbeanstalk.com/nuget
+warn : You are running the 'list source' operation with an 'HTTP' source,
+'ati-nugetserver' [http://atinugetserver-env..elasticbeanstalk.com/nuget]'.
+Non-HTTPS access will be removed in a future version. Consider migrating
+to an 'HTTPS' source."""
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_windows', True)
+    def test_dotnet_login_sources_listed_with_extra_non_list_text(self):
+
+        self.subprocess_check_output_patch.return_value = \
+            self._NUGET_SOURCES_LIST_RESPONSE_WITH_EXTRA_NON_LIST_TEXT
+
+        cmdline = self._setup_cmd(tool='dotnet')
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_operations_called(package_format='nuget', result=result)
+        commands = [[
+            'dotnet', 'nuget', 'list', 'source', '--format', 'detailed'
+        ]]
+        self._assert_subprocess_check_output_execution(commands)
+
     def test_npm_login_without_domain_owner(self):
         cmdline = self._setup_cmd(tool='npm')
         result = self.cli_runner.run(cmdline)
@@ -587,6 +618,30 @@ password: {auth_token}'''
         self._assert_operations_called(package_format='npm', result=result)
         self._assert_dry_run_execution(self._get_npm_commands(), result.stdout)
 
+    def test_npm_login_always_auth_error_ignored(self):
+        """Test login ignores error for always-auth.
+
+        This test is for NPM version >= 9 where the support of 'always-auth'
+        has been dropped. Running the command to set config gives a non-zero
+        exit code. This is to make sure that login ignores that error and all
+        other commands executes successfully.
+        """
+        def side_effect(command, capture_output, check):
+            if any('always-auth' in arg for arg in command):
+                raise subprocess.CalledProcessError(
+                    returncode=1,
+                    cmd=command
+                )
+
+            return mock.DEFAULT
+
+        self.subprocess_mock.side_effect = side_effect
+        cmdline = self._setup_cmd(tool='npm')
+        result = self.cli_runner.run(cmdline)
+        self.assertEqual(result.rc, 0)
+        self._assert_expiration_printed_to_stdout(result.stdout)
+        self._assert_subprocess_execution(self._get_npm_commands())
+
     def test_npm_login_with_domain_owner(self):
         cmdline = self._setup_cmd(tool='npm', include_domain_owner=True)
         result = self.cli_runner.run(cmdline)
