@@ -21,6 +21,8 @@ at the man output, we look one step before at the generated rst output
 (it's easier to verify).
 
 """
+import io
+
 from awscli.testutils import BaseAWSHelpOutputTest
 from awscli.testutils import FileCreator
 
@@ -46,9 +48,9 @@ class TestHelpOutput(BaseAWSHelpOutputTest):
         self.assert_contains('``--no-paginate``')
         # Arg with choices
         self.assert_contains('``--color``')
-        self.assert_contains('* on')
-        self.assert_contains('* off')
-        self.assert_contains('* auto')
+        self.assert_contains('*   on')
+        self.assert_contains('*   off')
+        self.assert_contains('*   auto')
         # Then we should see the services.
         self.assert_contains('* ec2')
         self.assert_contains('* s3api')
@@ -80,22 +82,23 @@ class TestHelpOutput(BaseAWSHelpOutputTest):
         self.assert_contains('Launches the specified number of instances')
         self.assert_contains('``--count`` (string)')
 
-    def test_waiter_does_not_have_duplicate_global_params_link(self):
-        self.driver.main(['ec2', 'wait', 'help'])
-        self.assert_contains_with_count(
-            'for descriptions of global parameters', 1)
-
     def test_custom_service_help_output(self):
         self.driver.main(['s3', 'help'])
         self.assert_contains('.. _cli:aws s3:')
         self.assert_contains('high-level S3 commands')
         self.assert_contains('* cp')
 
+    def test_waiter_does_not_have_global_args(self):
+        self.driver.main(['ec2', 'wait', 'help'])
+        self.assert_not_contains('--debug')
+        self.assert_not_contains('Global Options')
+
     def test_custom_operation_help_output(self):
         self.driver.main(['s3', 'ls', 'help'])
         self.assert_contains('.. _cli:aws s3 ls:')
         self.assert_contains('List S3 objects')
         self.assert_contains('--summarize')
+        self.assert_contains('--debug')
 
     def test_topic_list_help_output(self):
         self.driver.main(['help', 'topics'])
@@ -202,10 +205,10 @@ class TestRemoveDeprecatedCommands(BaseAWSHelpOutputTest):
         # command verify that we get a SystemExit exception
         # and that we get something in stderr that says that
         # we made an invalid choice (because the operation is removed).
-        stderr = six.StringIO()
+        stderr = io.StringIO()
         with mock.patch('sys.stderr', stderr):
-            with self.assertRaises(SystemExit):
-                self.driver.main([service, command, 'help'])
+            cr = self.driver.main([service, command, 'help'])
+        self.assertEqual(cr, 252)
         # We should see an error message complaining about
         # an invalid choice because the operation has been removed.
         self.assertIn('argument operation: Invalid choice', stderr.getvalue())
@@ -437,22 +440,15 @@ class TestIotData(BaseAWSHelpOutputTest):
         self.driver.main(['iot-data', 'help'])
         # Ensure the note is in help page.
         self.assert_contains(
-            'The default endpoint data.iot.[region].amazonaws.com is '
-            'intended for testing purposes only.')
+            'The default endpoints (intended for testing purposes only) can be found at '
+            'https://docs.aws.amazon.com/general/latest/gr/iot-core.html#iot-core-data-plane-endpoints')
 
     def test_operation_help_command_has_note(self):
         self.driver.main(['iot-data', 'get-thing-shadow', 'help'])
         # Ensure the note is in help page.
         self.assert_contains(
-            'The default endpoint data.iot.[region].amazonaws.com is '
-            'intended for testing purposes only.')
-
-
-class TestSMSVoice(BaseAWSHelpOutputTest):
-    def test_service_help_not_listed(self):
-        self.driver.main(['help'])
-        # Ensure the hidden service is not in the help listing.
-        self.assert_not_contains('* sms-voice')
+            'The default endpoints (intended for testing purposes only) can be found at '
+            'https://docs.aws.amazon.com/general/latest/gr/iot-core.html#iot-core-data-plane-endpoints')
 
 
 class TestAliases(BaseAWSHelpOutputTest):
