@@ -58,8 +58,8 @@ class TestBasicCommandFunctionality(unittest.TestCase):
         p = aws('help')
         self.assertEqual(p.rc, 0)
         self.assertIn('AWS', p.stdout)
-        self.assertRegexpMatches(
-            p.stdout, 'The\s+AWS\s+Command\s+Line\s+Interface')
+        self.assertRegex(
+            p.stdout, r'The\s+AWS\s+Command\s+Line\s+Interface')
 
     def test_service_help_output(self):
         p = aws('ec2 help')
@@ -74,25 +74,24 @@ class TestBasicCommandFunctionality(unittest.TestCase):
         # For now we're making the test less strict about formatting, but
         # we eventually should update this test to check exactly for
         # 'The describe-instances operation'.
-        self.assertRegexpMatches(p.stdout,
-                                 '\s+Describes\s+the\s+specified\s+instances')
+        self.assertRegex(p.stdout, r'\s+Describes\s+the\s+specified\s+instances')
 
     def test_topic_list_help_output(self):
         p = aws('help topics')
         self.assertEqual(p.rc, 0)
-        self.assertRegexpMatches(p.stdout, '\s+AWS\s+CLI\s+Topic\s+Guide')
-        self.assertRegexpMatches(
+        self.assertRegex(p.stdout, r'\s+AWS\s+CLI\s+Topic\s+Guide')
+        self.assertRegex(
             p.stdout,
-            '\s+This\s+is\s+the\s+AWS\s+CLI\s+Topic\s+Guide'
+            r'\s+This\s+is\s+the\s+AWS\s+CLI\s+Topic\s+Guide'
         )
 
     def test_topic_help_output(self):
         p = aws('help return-codes')
         self.assertEqual(p.rc, 0)
-        self.assertRegexpMatches(p.stdout, '\s+AWS\s+CLI\s+Return\s+Codes')
-        self.assertRegexpMatches(
+        self.assertRegex(p.stdout, r'\s+AWS\s+CLI\s+Return\s+Codes')
+        self.assertRegex(
             p.stdout,
-            'These\s+are\s+the\s+following\s+return\s+codes'
+            r'These\s+are\s+the\s+following\s+return\s+codes'
         )
 
     def test_operation_help_with_required_arg(self):
@@ -122,7 +121,7 @@ class TestBasicCommandFunctionality(unittest.TestCase):
         self.assertEqual(p.rc, 0, p.stderr)
         # Check text that appears in the warning block to ensure
         # the block was actually rendered.
-        self.assertRegexpMatches(p.stdout, 'To\s+receive\s+notifications')
+        self.assertRegex(p.stdout, r'To\s+receive\s+notifications')
 
     def test_param_shorthand(self):
         p = aws(
@@ -141,7 +140,7 @@ class TestBasicCommandFunctionality(unittest.TestCase):
         p = aws(
             'ec2 describe-instances --filters '
             '\'{"Name": "bad-filter", "Values": ["i-123"]}\'')
-        self.assertEqual(p.rc, 255)
+        self.assertEqual(p.rc, 254)
         self.assertIn("The filter 'bad-filter' is invalid", p.stderr,
                       "stdout: %s, stderr: %s" % (p.stdout, p.stderr))
 
@@ -187,7 +186,7 @@ class TestBasicCommandFunctionality(unittest.TestCase):
         p = aws('s3api get-object --bucket %s --key foo %s' % (
             bucket_name, os.path.join(d, 'foo')), env_vars=env_vars)
         # Should have credential issues.
-        self.assertEqual(p.rc, 255)
+        self.assertEqual(p.rc, 254)
 
         p = aws('s3api get-object --bucket %s --key foo '
                 '%s --no-sign-request' % (bucket_name, os.path.join(d, 'foo')),
@@ -247,7 +246,7 @@ class TestBasicCommandFunctionality(unittest.TestCase):
 
     def test_unknown_argument(self):
         p = aws('ec2 describe-instances --filterss')
-        self.assertEqual(p.rc, 255)
+        self.assertEqual(p.rc, 252)
         self.assertIn('Unknown options: --filterss', p.stderr)
 
     def test_table_output(self):
@@ -278,7 +277,7 @@ class TestBasicCommandFunctionality(unittest.TestCase):
 
     def test_leftover_args_in_operation(self):
         p = aws('ec2 describe-instances BADKEY=foo')
-        self.assertEqual(p.rc, 255)
+        self.assertEqual(p.rc, 252)
         self.assertIn("Unknown option", p.stderr, p.stderr)
 
     def test_json_param_parsing(self):
@@ -305,10 +304,8 @@ class TestBasicCommandFunctionality(unittest.TestCase):
 
     def test_error_msg_with_no_region_configured(self):
         environ = os.environ.copy()
-        try:
-            del environ['AWS_DEFAULT_REGION']
-        except KeyError:
-            pass
+        environ.pop('AWS_REGION', None)
+        environ.pop('AWS_DEFAULT_REGION', None)
         environ['AWS_CONFIG_FILE'] = 'nowhere-foo'
         p = aws('ec2 describe-instances', env_vars=environ)
         self.assertIn('must specify a region', p.stderr)
@@ -463,7 +460,7 @@ class TestGlobalArgs(BaseS3CLICommand):
         # private.
         p = aws('s3api head-object --bucket %s --key private --no-sign-request'
                 % bucket_name, env_vars=env)
-        self.assertEqual(p.rc, 255)
+        self.assertEqual(p.rc, 254)
 
     def test_profile_arg_has_precedence_over_env_vars(self):
         # At a high level, we're going to set access_key/secret_key
