@@ -10,17 +10,20 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
+import json
+
 import mock
 import tempfile
 import six
 from mock import patch, Mock, MagicMock, call
 import collections
 
-from awscli.testutils import unittest
 from awscli.customizations.cloudformation.deploy import DeployCommand
 from awscli.customizations.cloudformation.deployer import Deployer
 from awscli.customizations.cloudformation.yamlhelper import yaml_parse
 from awscli.customizations.cloudformation import exceptions
+from awscli.customizations.exceptions import ParamValidationError
+from tests.unit.customizations.cloudformation import BaseYAMLTest
 
 
 class FakeArgs(object):
@@ -43,9 +46,10 @@ def get_example_template():
 
 ChangeSetResult = collections.namedtuple("ChangeSetResult", ["changeset_id", "changeset_type"])
 
-class TestDeployCommand(unittest.TestCase):
+class TestDeployCommand(BaseYAMLTest):
 
     def setUp(self):
+        super(TestDeployCommand, self).setUp()
         self.session = mock.Mock()
         self.session.get_scoped_config.return_value = {}
         self.parsed_args = FakeArgs(template_file='./foo',
@@ -54,6 +58,7 @@ class TestDeployCommand(unittest.TestCase):
                                                          "Key2=Value2"],
                                     no_execute_changeset=False,
                                     execute_changeset=True,
+                                    disable_rollback=True,
                                     capabilities=None,
                                     role_arn=None,
                                     notification_arns=[],
@@ -89,7 +94,7 @@ class TestDeployCommand(unittest.TestCase):
             open_mock = mock.mock_open()
             # Patch the file open method to return template string
             with patch(
-                    "awscli.customizations.cloudformation.deploy.open",
+                    "awscli.customizations.cloudformation.deploy.compat_open",
                     open_mock(read_data=template_str)) as open_mock:
 
                 fake_template = get_example_template()
@@ -107,7 +112,6 @@ class TestDeployCommand(unittest.TestCase):
                 result = self.deploy_command._run_main(self.parsed_args,
                                               parsed_globals=self.parsed_globals)
                 self.assertEqual(0, result)
-
                 open_mock.assert_called_once_with(file_path, "r")
 
                 self.deploy_command.deploy.assert_called_once_with(
@@ -121,6 +125,7 @@ class TestDeployCommand(unittest.TestCase):
                     [],
                     None,
                     fake_tags,
+                    True,
                     True
                 )
 
@@ -146,6 +151,27 @@ class TestDeployCommand(unittest.TestCase):
             result = self.deploy_command._run_main(self.parsed_args,
                                                   parsed_globals=self.parsed_globals)
 
+    @patch('awscli.customizations.cloudformation.deploy.os.path.expanduser')
+    def test_expands_user_for_template_file(self, expanduser):
+        contents = (
+            'Resource:\n'
+            '  Test:\n'
+            '    Type: AWS::Foo::Bar\n'
+        )
+        with tempfile.NamedTemporaryFile('w') as f:
+            f.write(contents)
+            f.flush()
+            fake_expanduser_path = f.name + '.expanduser-file'
+            with open(fake_expanduser_path, 'w') as f:
+                f.write(contents)
+        # The tempfile is now gone so if we weren't using os.path.expanduser()
+        # in the code, this test would fail to load the file with an
+        # InvalidTemplatePathError.
+        expanduser.return_value = fake_expanduser_path
+        parsed, template_str, _ = self.deploy_command.load_template_file(f.name)
+        self.assertEqual(parsed, {'Resource': {'Test': {'Type': 'AWS::Foo::Bar'}}})
+        self.assertEqual(template_str, contents)
+
     @patch('awscli.customizations.cloudformation.deploy.os.path.isfile')
     @patch('awscli.customizations.cloudformation.deploy.yaml_parse')
     @patch('awscli.customizations.cloudformation.deploy.os.path.getsize')
@@ -161,7 +187,7 @@ class TestDeployCommand(unittest.TestCase):
         open_mock = mock.mock_open()
 
         with patch(
-                "awscli.customizations.cloudformation.deploy.open",
+                "awscli.customizations.cloudformation.deploy.compat_open",
                 open_mock(read_data=template_str)) as open_mock:
             with self.assertRaises(exceptions.DeployBucketRequiredError):
                 result = self.deploy_command._run_main(self.parsed_args,
@@ -186,7 +212,7 @@ class TestDeployCommand(unittest.TestCase):
         open_mock = mock.mock_open()
 
         with patch(
-                "awscli.customizations.cloudformation.deploy.open",
+                "awscli.customizations.cloudformation.deploy.compat_open",
                 open_mock(read_data=template_str)) as open_mock:
 
             self.parsed_args.s3_bucket = bucket_name
@@ -207,6 +233,7 @@ class TestDeployCommand(unittest.TestCase):
                 [],
                 s3UploaderObject,
                 [{"Key": "tagkey1", "Value": "tagvalue1"}],
+                True,
                 True
             )
 
@@ -259,7 +286,7 @@ class TestDeployCommand(unittest.TestCase):
                                                      tags=tags)
 
         # since execute_changeset is set to True, deploy() will execute changeset
-        self.deployer.execute_changeset.assert_called_once_with(changeset_id, stack_name)
+        self.deployer.execute_changeset.assert_called_once_with(changeset_id, stack_name, False)
         self.deployer.wait_for_execute.assert_called_once_with(stack_name, changeset_type)
 
 
@@ -344,7 +371,7 @@ class TestDeployCommand(unittest.TestCase):
             self.deploy_command.deploy(
                 self.deployer, stack_name, template, parameters, capabilities,
                 execute_changeset, role_arn, notification_arns,
-                None, tags)
+                None, tags, fail_on_empty_changeset=True)
 
     def test_deploy_does_not_raise_exception_on_empty_changeset(self):
         stack_name = "stack_name"
@@ -365,6 +392,24 @@ class TestDeployCommand(unittest.TestCase):
             fail_on_empty_changeset=False
         )
 
+    def test_deploy_empty_changeset_does_not_raise_exception_by_default(self):
+        stack_name = "stack_name"
+        parameters = ["a", "b"]
+        template = "cloudformation template"
+        capabilities = ["foo", "bar"]
+        execute_changeset = True
+        role_arn = "arn:aws:iam::1234567890:role"
+        notification_arns = ["arn:aws:sns:region:1234567890:notify"]
+
+        empty_changeset = exceptions.ChangeEmptyError(stack_name=stack_name)
+        changeset_func = self.deployer.create_and_wait_for_changeset
+        changeset_func.side_effect = empty_changeset
+        self.deploy_command.deploy(
+            self.deployer, stack_name, template, parameters, capabilities,
+            execute_changeset, role_arn, notification_arns,
+            s3_uploader=None, tags=[]
+        )
+
     def test_parse_key_value_arg_success(self):
         """
         Tests that we can parse parameter arguments provided in proper format
@@ -382,6 +427,105 @@ class TestDeployCommand(unittest.TestCase):
         result = self.deploy_command.parse_key_value_arg([], argname)
         self.assertEqual(result, {})
 
+    def test_parse_parameter_override_with_cf_data_format(self):
+        """
+        Tests that we can parse parameter arguments from file in
+        CloudFormation parameters file format
+        :return:
+        """
+        data = json.dumps([
+            {'ParameterKey': 'Key1',
+             'ParameterValue': 'Value1'},
+            {'ParameterKey': 'Key2',
+             'ParameterValue': '[1,2,3]'},
+            {'ParameterKey': 'Key3',
+             'ParameterValue': '{"a":"val", "b": 2}'}
+        ])
+        output = {"Key1": "Value1",
+                  "Key2": '[1,2,3]',
+                  "Key3": '{"a":"val", "b": 2}'}
+        result = self.deploy_command.parse_parameter_overrides(data)
+        self.assertEqual(result, output)
+
+    def test_validate_parameter_override_with_cf_data_format(self):
+        """
+        Tests that we through exception if have redundant keys in json
+        CloudFormation parameters file format
+        :return:
+        """
+        data = json.dumps([
+            {'ParameterKey': 'Key1',
+             'ParameterValue': 'Value1',
+             'RedundantKey': 'foo'}
+        ])
+        with self.assertRaises(ParamValidationError):
+            self.deploy_command.parse_parameter_overrides(data)
+
+    def test_parse_parameter_override_with_codepipeline_data_format(self):
+        """
+        Tests that we can parse parameter arguments from file in
+        CodePipeline parameters file format
+        :return:
+        """
+        data = json.dumps({
+            'Parameters': {
+                "Key1": "Value1",
+                "Key2": '[1,2,3]',
+                "Key3": '{"a":"val", "b": 2}'
+            }
+        })
+        output = {"Key1": "Value1",
+                  "Key2": '[1,2,3]',
+                  "Key3": '{"a":"val", "b": 2}'}
+        result = self.deploy_command.parse_parameter_overrides(data)
+        self.assertEqual(result, output)
+
+    def test_parse_parameter_override_with_deploy_data_format_from_file(self):
+        """
+        Tests that we can parse parameter arguments from file in
+        deploy command parameters file format
+        :return:
+        """
+        data = json.dumps([
+            'Key1=Value1',
+            'Key2=[1,2,3]',
+            'Key3={"a":"val", "b": 2}'
+        ])
+        output = {"Key1": "Value1",
+                  "Key2": '[1,2,3]',
+                  "Key3": '{"a":"val", "b": 2}'}
+        result = self.deploy_command.parse_parameter_overrides(data)
+        self.assertEqual(result, output)
+
+    def test_parse_parameter_override_with_inline_json(self):
+        data = [json.dumps([
+            'Key1=Value1',
+            'Key2=[1,2,3]',
+            'Key3={"a":"val", "b": 2}'
+        ])]
+        output = {"Key1": "Value1",
+                  "Key2": '[1,2,3]',
+                  "Key3": '{"a":"val", "b": 2}'}
+        result = self.deploy_command.parse_parameter_overrides(data)
+        self.assertEqual(result, output)
+
+    def test_parse_parameter_override_with_deploy_data_format(self):
+        """
+        Tests that we can parse parameter arguments in
+        deploy command parameters command line format
+        :return:
+        """
+        data = [
+            'Key1=Value1',
+            'Key2=[1,2,3]',
+            'Key3={"a":"val", "b": 2}'
+        ]
+        output = {"Key1": "Value1",
+                  "Key2": '[1,2,3]',
+                  "Key3": '{"a":"val", "b": 2}'}
+        result = self.deploy_command.parse_parameter_overrides(data)
+        self.assertEqual(result, output)
+
     def test_parse_key_value_arg_invalid_input(self):
         # non-list input
         argname = "parameter-overrides"
