@@ -18,9 +18,13 @@ import gzip
 from datetime import datetime, timedelta
 from dateutil import parser, tz
 
-import rsa
 from mock import Mock, call
 from argparse import Namespace
+from cryptography.hazmat.backends import default_backend
+from cryptography.hazmat.primitives import hashes
+from cryptography.hazmat.primitives.asymmetric import rsa
+from cryptography.hazmat.primitives.asymmetric.padding import PKCS1v15
+from cryptography.hazmat.primitives.serialization import Encoding, PublicFormat
 
 from awscli.compat import six
 from awscli.testutils import BaseAWSCommandParamsTest
@@ -32,7 +36,7 @@ from awscli.customizations.cloudtrail.validation import DigestError, \
     InvalidDigestFormat, S3ClientProvider
 from botocore.exceptions import ClientError
 from awscli.testutils import unittest
-from awscli.schema import ParameterRequiredError
+from awscli.customizations.exceptions import ParamValidationError
 
 
 START_DATE = parser.parse('20140810T000000Z')
@@ -180,7 +184,7 @@ class TestValidation(unittest.TestCase):
         try:
             parse_date('foo')
             self.fail('Should have failed to parse')
-        except ValueError as e:
+        except ParamValidationError as e:
             self.assertIn('Unable to parse date value: foo', str(e))
 
     def test_parses_dates(self):
@@ -191,7 +195,7 @@ class TestValidation(unittest.TestCase):
         try:
             assert_cloudtrail_arn_is_valid('foo:bar:baz')
             self.fail('Should have failed')
-        except ValueError as e:
+        except ParamValidationError as e:
             self.assertIn('Invalid trail ARN provided: foo:bar:baz', str(e))
 
     def test_ensures_cloudtrail_arns_are_valid_when_missing_resource(self):
@@ -199,7 +203,7 @@ class TestValidation(unittest.TestCase):
             assert_cloudtrail_arn_is_valid(
                 'arn:aws:cloudtrail:us-east-1:%s:foo' % TEST_ACCOUNT_ID)
             self.fail('Should have failed')
-        except ValueError as e:
+        except ParamValidationError as e:
             self.assertIn('Invalid trail ARN provided', str(e))
 
     def test_allows_valid_arns(self):
@@ -339,7 +343,7 @@ class TestValidation(unittest.TestCase):
                 "Id": TEST_ORGANIZATION_ID,
             }
         }
-        with self.assertRaises(ParameterRequiredError):
+        with self.assertRaises(ParamValidationError):
             create_digest_traverser(
                 trail_arn=TEST_TRAIL_ARN, trail_source_region='us-east-1',
                 cloudtrail_client=cloudtrail_client,
@@ -381,7 +385,7 @@ class TestSha256RSADigestValidator(unittest.TestCase):
         self._digest_data['_signature'] = 'aeff'
 
     def test_validates_digests(self):
-        (public_key, private_key) = rsa.newkeys(512)
+        private_key = rsa.generate_private_key(65537, 512, default_backend())
         sha256_hash = hashlib.sha256(self._inflated_digest)
         string_to_sign = "%s\n%s/%s\n%s\n%s" % (
             self._digest_data['digestEndTime'],
@@ -389,10 +393,13 @@ class TestSha256RSADigestValidator(unittest.TestCase):
             self._digest_data['digestS3Object'],
             sha256_hash.hexdigest(),
             self._digest_data['previousDigestSignature'])
-        signature = rsa.sign(string_to_sign.encode(), private_key, 'SHA-256')
+        to_sign = string_to_sign.encode()
+        signature = private_key.sign(to_sign, PKCS1v15(), hashes.SHA256())
         self._digest_data['_signature'] = binascii.hexlify(signature)
         validator = Sha256RSADigestValidator()
-        public_key_b64 = base64.b64encode(public_key.save_pkcs1(format='DER'))
+        public_key = private_key.public_key()
+        pub_bytes = public_key.public_bytes(Encoding.DER, PublicFormat.PKCS1)
+        public_key_b64 = base64.b64encode(pub_bytes)
         validator.validate('b', 'k', public_key_b64, self._digest_data,
                            self._inflated_digest)
 
@@ -824,7 +831,7 @@ class TestDigestTraverser(unittest.TestCase):
         self.assertEqual(
             2, len(digest_provider.calls['load_digest_keys_in_range']))
         self.assertEqual(['1', '1', '2', '2'],
-                         [c['digestS3Bucket'] for c in collected])
+                          [c['digestS3Bucket'] for c in collected])
 
     def test_does_not_hard_fail_on_invalid_signature(self):
         start_date = START_DATE
