@@ -1,12 +1,15 @@
 import errno
 import os
+import subprocess
 
 from datetime import datetime
 from dateutil.tz import tzlocal, tzutc
 from dateutil.relativedelta import relativedelta
 
+from configparser import RawConfigParser
+from urllib.parse import urlsplit
+
 from awscli.testutils import unittest, mock, FileCreator
-from awscli.compat import urlparse, RawConfigParser, StringIO
 from awscli.customizations.codeartifact.login import (
     BaseLogin, NuGetLogin, DotNetLogin, NpmLogin, PipLogin, TwineLogin,
     get_relative_expiration_time
@@ -48,16 +51,15 @@ class TestBaseLogin(unittest.TestCase):
             )
 
     def test_run_commands_nonexistent_command(self):
-        self.subprocess_utils.check_call.side_effect = OSError(
+        self.subprocess_utils.run.side_effect = OSError(
             errno.ENOENT, 'not found error'
         )
         tool = 'NotSupported'
-        with self.assertRaisesRegex(
-                ValueError, '%s was not found.' % tool):
+        with self.assertRaisesRegex(ValueError, f'{tool} was not found.'):
             self.test_subject._run_commands(tool, ['echo', tool])
 
     def test_run_commands_unhandled_error(self):
-        self.subprocess_utils.check_call.side_effect = OSError(
+        self.subprocess_utils.run.side_effect = OSError(
             errno.ENOSYS, 'unhandled error'
         )
         tool = 'NotSupported'
@@ -242,6 +244,19 @@ Registered Sources:
   2. Ab[.d7  $#!],   [Disabled]
      https://source2.com/index.json"""
 
+    _NUGET_SOURCES_LIST_RESPONSE_WITH_EXTRA_NON_LIST_TEXT = b"""\
+Welcome to dotnet 2.0!
+
+Registered Sources:
+  1. Source Name 1 [Enabled]
+     https://source1.com/index.json
+  2. ati-nugetserver [Disabled]
+     http://atinugetserver-env.elasticbeanstalk.com/nuget
+warn : You are running the 'list source' operation with an 'HTTP' source,
+'ati-nugetserver' [http://atinugetserver-env..elasticbeanstalk.com/nuget]'.
+Non-HTTPS access will be removed in a future version. Consider migrating
+to an 'HTTPS' source."""
+
     def setUp(self):
         self.domain = 'domain'
         self.domain_owner = 'domain-owner'
@@ -336,6 +351,43 @@ Registered Sources:
             stderr=self.subprocess_utils.PIPE
         )
 
+    @mock.patch('awscli.customizations.codeartifact.login.is_windows', False)
+    def test_login_sources_listed_with_extra_non_list_text(self):
+        self.subprocess_utils.check_output.return_value = \
+            self._NUGET_SOURCES_LIST_RESPONSE_WITH_EXTRA_NON_LIST_TEXT
+        self.test_subject.login()
+        self.subprocess_utils.check_output.assert_any_call(
+            self.list_operation_command,
+            stderr=self.subprocess_utils.PIPE
+        )
+        self.subprocess_utils.check_output.assert_called_with(
+            self.add_operation_command_non_windows,
+            stderr=self.subprocess_utils.PIPE
+        )
+
+    @mock.patch('awscli.customizations.codeartifact.login.is_windows', True)
+    def test_login_sources_listed_with_extra_non_list_text_on_windows(self):
+        self.subprocess_utils.check_output.return_value = \
+            self._NUGET_SOURCES_LIST_RESPONSE_WITH_EXTRA_NON_LIST_TEXT
+        self.test_subject.login()
+        self.subprocess_utils.check_output.assert_any_call(
+            self.list_operation_command,
+            stderr=self.subprocess_utils.PIPE
+        )
+        self.subprocess_utils.check_output.assert_called_with(
+            self.add_operation_command_windows,
+            stderr=self.subprocess_utils.PIPE
+        )
+
+    def test_login_sources_listed_with_extra_non_list_text_dry_run(self):
+        self.subprocess_utils.check_output.return_value = \
+                self._NUGET_SOURCES_LIST_RESPONSE_WITH_EXTRA_NON_LIST_TEXT
+        self.test_subject.login(dry_run=True)
+        self.subprocess_utils.check_output.assert_called_once_with(
+            self.list_operation_command,
+            stderr=self.subprocess_utils.PIPE
+        )
+
     @mock.patch('awscli.customizations.codeartifact.login.is_windows', False)
     def test_login_source_name_already_exists(self):
         list_response = 'Registered Sources:\n' \
@@ -412,7 +464,7 @@ class TestNpmLogin(unittest.TestCase):
                 repository=self.repository
             )
 
-        repo_uri = urlparse.urlsplit(self.endpoint)
+        repo_uri = urlsplit(self.endpoint)
         always_auth_config = '//{}{}:always-auth'.format(
             repo_uri.netloc, repo_uri.path
         )
@@ -442,11 +494,44 @@ class TestNpmLogin(unittest.TestCase):
         expected_calls = [
             mock.call(
                 command,
-                stdout=self.subprocess_utils.PIPE,
-                stderr=self.subprocess_utils.PIPE,
+                capture_output=True,
+                check=True
             ) for command in self.commands
         ]
-        self.subprocess_utils.check_call.assert_has_calls(
+        self.subprocess_utils.run.assert_has_calls(
+            expected_calls, any_order=True
+        )
+
+    def test_login_always_auth_error_ignored(self):
+        """Test login ignores error for always-auth.
+
+        This test is for NPM version >= 9 where the support of 'always-auth'
+        has been dropped. Running the command to set config gives a non-zero
+        exit code. This is to make sure that login ignores that error and all
+        other commands executes successfully.
+        """
+        def side_effect(command, capture_output, check):
+            """Set side_effect for always-auth config setting command"""
+            if any('always-auth' in arg for arg in command):
+                raise subprocess.CalledProcessError(
+                    returncode=1,
+                    cmd=command
+                )
+
+            return mock.DEFAULT
+
+        self.subprocess_utils.run.side_effect = side_effect
+        expected_calls = []
+
+        for command in self.commands:
+            expected_calls.append(mock.call(
+                command,
+                capture_output=True,
+                check=True
+            ))
+        self.test_subject.login()
+
+        self.subprocess_utils.run.assert_has_calls(
             expected_calls, any_order=True
         )
 
@@ -484,7 +569,7 @@ class TestNpmLogin(unittest.TestCase):
 
     def test_login_dry_run(self):
         self.test_subject.login(dry_run=True)
-        self.subprocess_utils.check_call.assert_not_called()
+        self.subprocess_utils.assert_not_called()
 
 
 class TestPipLogin(unittest.TestCase):
@@ -507,7 +592,7 @@ class TestPipLogin(unittest.TestCase):
                 repository=self.repository
             )
 
-        repo_uri = urlparse.urlsplit(self.endpoint)
+        repo_uri = urlsplit(self.endpoint)
         self.pip_index_url = self.PIP_INDEX_URL_FMT.format(
             scheme=repo_uri.scheme,
             auth_token=self.auth_token,
@@ -533,15 +618,15 @@ class TestPipLogin(unittest.TestCase):
 
     def test_login(self):
         self.test_subject.login()
-        self.subprocess_utils.check_call.assert_called_once_with(
+        self.subprocess_utils.run.assert_called_once_with(
             ['pip', 'config', 'set', 'global.index-url', self.pip_index_url],
-            stdout=self.subprocess_utils.PIPE,
-            stderr=self.subprocess_utils.PIPE,
+            capture_output=True,
+            check=True
         )
 
     def test_login_dry_run(self):
         self.test_subject.login(dry_run=True)
-        self.subprocess_utils.check_call.assert_not_called()
+        self.subprocess_utils.assert_not_called()
 
 
 class TestTwineLogin(unittest.TestCase):
@@ -590,7 +675,7 @@ class TestTwineLogin(unittest.TestCase):
         self, pypi_rc_str, server, repo_url=None, username=None, password=None
     ):
         pypi_rc = RawConfigParser()
-        pypi_rc.readfp(StringIO(pypi_rc_str))
+        pypi_rc.read_string(pypi_rc_str)
 
         self.assertIn('distutils', pypi_rc.sections())
         self.assertIn('index-servers', pypi_rc.options('distutils'))
@@ -640,7 +725,7 @@ class TestTwineLogin(unittest.TestCase):
 
     def test_login_dry_run(self):
         self.test_subject.login(dry_run=True)
-        self.subprocess_utils.check_call.assert_not_called()
+        self.subprocess_utils.assert_not_called()
         self.assertFalse(os.path.exists(self.test_pypi_rc_path))
 
     def test_login_existing_pypi_rc_not_clobbered(self):
