@@ -262,7 +262,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
         expected_error_msg = (
             '\naws: error: You cannot specify both --ami-version'
             ' and --release-label options together.\n')
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expected_error_msg, result[1])
 
     def test_if_ami_version_or_release_label_is_provided(self):
@@ -270,7 +270,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
                DEFAULT_INSTANCE_GROUPS_ARG)
         expected_error_msg = ('\naws: error: Either --ami-version or'
                               ' --release-label is required.\n')
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expected_error_msg, result[1])
 
     def test_no_special_steps_added_for_applications(self):
@@ -369,7 +369,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
             'and --ec2-attributes InstanceProfile options together. Either '
             'choose --use-default-roles or use both --service-role <roleName>'
             ' and --ec2-attributes InstanceProfile=<profileName>.\n')
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expected_error_msg, result[1])
 
     def test_mutual_exclusive_use_default_roles_and_instance_profile(self):
@@ -380,7 +380,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
             'and --service-role options together. Either choose '
             '--use-default-roles or use both --service-role <roleName> '
             'and --ec2-attributes InstanceProfile=<profileName>.\n')
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expected_error_msg, result[1])
 
     def test_cluster_name_no_space(self):
@@ -432,7 +432,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
         expected_error_msg = (
             '\naws: error: cannot use both --no-auto-terminate and'
             ' --auto-terminate options together.\n')
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expected_error_msg, result[1])
 
     def test_termination_protected(self):
@@ -453,7 +453,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
         expected_error_msg = (
             '\naws: error: cannot use both --termination-protected'
             ' and --no-termination-protected options together.\n')
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expected_error_msg, result[1])
 
     def test_visible_to_all_users(self):
@@ -471,7 +471,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
         expected_error_msg = (
             '\naws: error: cannot use both --visible-to-all-users and '
             '--no-visible-to-all-users options together.\n')
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expected_error_msg, result[1])
 
     def test_tags(self):
@@ -516,7 +516,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
         expected_error_msg = (
             '\naws: error: LogUri not specified. You must specify a logUri'
             ' if you enable debugging when creating a cluster.\n')
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expected_error_msg, result[1])
 
     def test_enable_debugging_and_no_enable_debugging(self):
@@ -525,7 +525,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
         expected_error_msg = (
             '\naws: error: cannot use both --enable-debugging and '
             '--no-enable-debugging options together.\n')
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expected_error_msg, result[1])
 
     def test_instance_groups_default_name_market(self):
@@ -593,7 +593,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
             '\naws: error: Must specify either --instance-groups or '
             '--instance-type with --instance-count(optional) to '
             'configure instance groups.\n')
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expect_error_msg, result[1])
 
         cmd = (
@@ -603,7 +603,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
             '\naws: error: Must specify either --instance-groups or '
             '--instance-type with --instance-count(optional) to '
             'configure instance groups.\n')
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expect_error_msg, result[1])
 
     def test_instance_groups_exclusive_parameter_validation_error(self):
@@ -616,7 +616,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
             'or --instance-count with --instance-groups, '
             'because --instance-type and --instance-count are '
             'shortcut options for --instance-groups.\n')
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expect_error_msg, result[1])
 
         cmd = (
@@ -628,7 +628,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
             'or --instance-count with --instance-groups, '
             'because --instance-type and --instance-count are '
             'shortcut options for --instance-groups.\n')
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expect_error_msg, result[1])
 
     def test_instance_groups_missing_instance_group_type_error(self):
@@ -637,7 +637,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
             '--auto-terminate '
             '--instance-groups '
             'Name=Master,InstanceCount=1,InstanceType=m1.small')
-        stderr = self.run_cmd(cmd, 255)[1]
+        stderr = self.run_cmd(cmd, 252)[1]
         self.assert_error_message_has_field_name(stderr, 'InstanceGroupType')
 
     def test_instance_groups_missing_instance_type_error(self):
@@ -649,7 +649,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
         expect_error_msg = (
             '\nThe following required parameters are missing'
             ' for structure:: InstanceType\n')
-        stderr = self.run_cmd(cmd, 255)[1]
+        stderr = self.run_cmd(cmd, 252)[1]
         self.assert_error_message_has_field_name(stderr, 'InstanceType')
 
     def test_instance_groups_missing_instance_count_error(self):
@@ -658,7 +658,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
             '--auto-terminate '
             '--instance-groups '
             'Name=Master,InstanceGroupType=MASTER,InstanceType=m1.xlarge')
-        stderr = self.run_cmd(cmd, 255)[1]
+        stderr = self.run_cmd(cmd, 252)[1]
         self.assert_error_message_has_field_name(stderr, 'InstanceCount')
 
     def test_instance_groups_from_json_file(self):
@@ -765,7 +765,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
         expect_error_msg = (
             '\naws: error: You may not specify both a SubnetId and an Availab'
             'ilityZone (placement) because ec2SubnetId implies a placement.\n')
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expect_error_msg, result[1])
 
     def test_ec2_attributes_with_subnet_from_json_file(self):
@@ -797,7 +797,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
     # Bootstrap Actions test cases
     def test_bootstrap_actions_missing_path_error(self):
         cmd = DEFAULT_CMD + '--bootstrap-actions Name=ba1,Args=arg1,arg2'
-        stderr = self.run_cmd(cmd, 255)[1]
+        stderr = self.run_cmd(cmd, 252)[1]
         self.assert_error_message_has_field_name(stderr, 'Path')
 
     def test_bootstrap_actions_with_all_fields(self):
@@ -818,7 +818,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
 
         expected_error_msg = '\naws: error: maximum number of ' +\
                              'bootstrap actions for a cluster exceeded.\n'
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
 
         self.assertEqual(expected_error_msg, result[1])
 
@@ -829,7 +829,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
             cmd += ba_cmd
         expected_error_msg = '\naws: error: maximum number of ' +\
                              'bootstrap actions for a cluster exceeded.\n'
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expected_error_msg, result[1])
 
     def test_boostrap_actions_with_default_fields(self):
@@ -874,7 +874,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
         cmd = DEFAULT_CMD + '--steps Type=unknown'
         expected_error_msg = (
             '\naws: error: The step type unknown is not supported.\n')
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expected_error_msg, result[1])
 
     def test_default_step_type_name_action_on_failure(self):
@@ -887,7 +887,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
         cmd = DEFAULT_CMD + '--steps Name=CustomJarMissingJar'
         expect_error_msg = '\naws: error: The following ' + \
             'required parameters are missing for CustomJARStepConfig: Jar.\n'
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expect_error_msg, result[1])
 
     def test_custom_jar_step_with_all_fields(self):
@@ -923,7 +923,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
         cmd = DEFAULT_CMD + '--steps Type=Streaming'
         expect_error_msg = '\naws: error: The following ' + \
             'required parameters are missing for StreamingStepConfig: Args.\n'
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expect_error_msg, result[1])
 
     def test_streaming_jar_with_all_fields(self):
@@ -951,7 +951,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
         cmd = DEFAULT_CMD + '--applications Name=Hive --steps Type=Hive'
         expect_error_msg = '\naws: error: The following ' + \
             'required parameters are missing for HiveStepConfig: Args.\n'
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expect_error_msg, result[1])
 
     def test_hive_step_with_all_fields(self):
@@ -977,7 +977,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
         cmd = DEFAULT_CMD + '--applications Name=Pig --steps Type=Pig'
         expect_error_msg = '\naws: error: The following ' + \
             'required parameters are missing for PigStepConfig: Args.\n'
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expect_error_msg, result[1])
 
     def test_pig_step_with_all_fields(self):
@@ -1100,9 +1100,9 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
         expected_error_msg = (
             '\naws: error: Must specify --auto-scaling-role when'
             ' configuring an AutoScaling policy for an instance group.\n')
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expected_error_msg, result[1])
-        
+
     def test_scale_down_behavior(self):
         cmd = (self.prefix + '--release-label emr-4.0.0 --scale-down-behavior TERMINATE_AT_INSTANCE_HOUR '
                              '--instance-groups ' + DEFAULT_INSTANCE_GROUPS_ARG)
@@ -1136,13 +1136,13 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
     def test_instance_groups_with_ebs_config_missing_volume_type(self):
         cmd = (self.prefix + '--release-label emr-4.2.0 --instance-groups ' +
                CONSTANTS.INSTANCE_GROUPS_WITH_EBS_VOLUME_MISSING_VOLTYPE_ARG)
-        stderr = self.run_cmd(cmd, 255)[1]
+        stderr = self.run_cmd(cmd, 252)[1]
         self.assert_error_message_has_field_name(stderr, 'VolumeType')
 
     def test_instance_groups_with_ebs_config_missing_size(self):
         cmd = (self.prefix + '--release-label emr-4.2.0 --instance-groups ' +
                CONSTANTS.INSTANCE_GROUPS_WITH_EBS_VOLUME_MISSING_SIZE_ARG)
-        stderr = self.run_cmd(cmd, 255)[1]
+        stderr = self.run_cmd(cmd, 252)[1]
         self.assert_error_message_has_field_name(stderr, 'SizeInGB')
 
     def test_instance_groups_with_ebs_config_missing_volume_spec(self):
@@ -1310,7 +1310,7 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
         expected_error_msg = (
             '\naws: error: You cannot specify both --instance-groups'
             ' and --instance-fleets options together.\n')
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expected_error_msg, result[1])
 
     def test_instance_fleets_with_both_subnetid_subnetids_specified(self):
@@ -1320,11 +1320,11 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
         expected_error_msg = (
             '\naws: error: You cannot specify both SubnetId'
             ' and SubnetIds options together.\n')
-        result = self.run_cmd(cmd, 255)
+        result = self.run_cmd(cmd, 252)
         self.assertEqual(expected_error_msg, result[1])
 
     def test_create_cluster_with_security_config(self):
-        cmd = (self.prefix + '--release-label emr-4.7.2 --security-configuration MySecurityConfig '+ 
+        cmd = (self.prefix + '--release-label emr-4.7.2 --security-configuration MySecurityConfig '+
                '--instance-groups ' + DEFAULT_INSTANCE_GROUPS_ARG)
         result = \
             {
@@ -1496,6 +1496,21 @@ class TestCreateCluster(BaseAWSCommandParamsTest):
             }
         self.assert_params_for_cmd(cmd, result)
 
+    def test_create_cluster_with_os_release_label(self):
+        test_os_release_label = '2.0.20220406.1'
+        cmd = (self.prefix + '--release-label emr-6.6.0' 
+                + ' --os-release-label ' + test_os_release_label 
+                + ' --instance-groups ' + DEFAULT_INSTANCE_GROUPS_ARG)
+        result = \
+             {
+                  'Name': DEFAULT_CLUSTER_NAME,
+                  'Instances': DEFAULT_INSTANCES,
+                  'ReleaseLabel': 'emr-6.6.0',
+                  'VisibleToAllUsers': True,
+                  'Tags': [],
+                  'OSReleaseLabel': test_os_release_label
+             }
+        self.assert_params_for_cmd(cmd, result)
 
 if __name__ == "__main__":
     unittest.main()
