@@ -10,26 +10,22 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-import json
-import os
+from awscli.testutils import unittest, skip_if_windows, FileCreator
 import signal
+import json
 import sys
+import os
 
+import mock
+
+from awscli.compat import six
+from awscli.help import PosixHelpRenderer, ExecutableNotFoundError
+from awscli.help import WindowsHelpRenderer, ProviderHelpCommand, HelpCommand
+from awscli.help import TopicListerCommand, TopicHelpCommand
 from awscli.argparser import HELP_BLURB, ArgParseException
-from awscli.compat import StringIO
-from awscli.help import (
-    ExecutableNotFoundError,
-    HelpCommand,
-    PosixHelpRenderer,
-    ProviderHelpCommand,
-    TopicHelpCommand,
-    TopicListerCommand,
-    WindowsHelpRenderer,
-)
-from awscli.testutils import FileCreator, mock, skip_if_windows, unittest
 
 
-class HelpSpyMixin:
+class HelpSpyMixin(object):
     def __init__(self):
         self.exists_on_path = {}
         self.popen_calls = []
@@ -56,6 +52,7 @@ class FakeWindowsHelpRenderer(HelpSpyMixin, WindowsHelpRenderer):
 
 
 class TestHelpPager(unittest.TestCase):
+
     def setUp(self):
         self.environ = {}
         self.environ_patch = mock.patch('os.environ', self.environ)
@@ -66,34 +63,38 @@ class TestHelpPager(unittest.TestCase):
         self.environ_patch.stop()
 
     def test_no_env_vars(self):
-        self.assertEqual(
-            self.renderer.get_pager_cmdline(), self.renderer.PAGER.split()
-        )
+        self.assertEqual(self.renderer.get_pager_cmdline(),
+                         self.renderer.PAGER.split())
 
     def test_manpager(self):
         pager_cmd = 'foobar'
         os.environ['MANPAGER'] = pager_cmd
-        self.assertEqual(self.renderer.get_pager_cmdline(), pager_cmd.split())
+        self.assertEqual(self.renderer.get_pager_cmdline(),
+                         pager_cmd.split())
 
     def test_pager(self):
         pager_cmd = 'fiebaz'
         os.environ['PAGER'] = pager_cmd
-        self.assertEqual(self.renderer.get_pager_cmdline(), pager_cmd.split())
+        self.assertEqual(self.renderer.get_pager_cmdline(),
+                         pager_cmd.split())
 
     def test_both(self):
         os.environ['MANPAGER'] = 'foobar'
         os.environ['PAGER'] = 'fiebaz'
-        self.assertEqual(self.renderer.get_pager_cmdline(), 'foobar'.split())
+        self.assertEqual(self.renderer.get_pager_cmdline(),
+                         'foobar'.split())
 
     def test_manpager_with_args(self):
         pager_cmd = 'less -X'
         os.environ['MANPAGER'] = pager_cmd
-        self.assertEqual(self.renderer.get_pager_cmdline(), pager_cmd.split())
+        self.assertEqual(self.renderer.get_pager_cmdline(),
+                         pager_cmd.split())
 
     def test_pager_with_args(self):
         pager_cmd = 'less -X --clearscreen'
         os.environ['PAGER'] = pager_cmd
-        self.assertEqual(self.renderer.get_pager_cmdline(), pager_cmd.split())
+        self.assertEqual(self.renderer.get_pager_cmdline(),
+                         pager_cmd.split())
 
     @skip_if_windows('Requires posix system.')
     def test_no_groff_or_mandoc_exists(self):
@@ -106,7 +107,7 @@ class TestHelpPager(unittest.TestCase):
 
     @skip_if_windows('Requires POSIX system.')
     def test_renderer_falls_back_to_mandoc(self):
-        stdout = StringIO()
+        stdout = six.StringIO()
         renderer = FakePosixHelpRenderer(output_stream=stdout)
 
         renderer.exists_on_path['groff'] = False
@@ -119,7 +120,7 @@ class TestHelpPager(unittest.TestCase):
     def test_no_pager_exists(self):
         fake_pager = 'foobar'
         os.environ['MANPAGER'] = fake_pager
-        stdout = StringIO()
+        stdout = six.StringIO()
         renderer = FakePosixHelpRenderer(output_stream=stdout)
         renderer.exists_on_path[fake_pager] = False
 
@@ -131,10 +132,8 @@ class TestHelpPager(unittest.TestCase):
     def test_shlex_split_for_pager_var(self):
         pager_cmd = '/bin/sh -c "col -bx | vim -c \'set ft=man\' -"'
         os.environ['PAGER'] = pager_cmd
-        self.assertEqual(
-            self.renderer.get_pager_cmdline(),
-            ['/bin/sh', '-c', "col -bx | vim -c 'set ft=man' -"],
-        )
+        self.assertEqual(self.renderer.get_pager_cmdline(),
+                         ['/bin/sh', '-c', "col -bx | vim -c 'set ft=man' -"])
 
     def test_can_render_contents(self):
         renderer = FakePosixHelpRenderer()
@@ -195,7 +194,6 @@ class TestHelpCommand(TestHelpCommandBase):
     We do this by subclassing from HelpCommand and ensure it is behaving
     as expected.
     """
-
     def setUp(self):
         super(TestHelpCommand, self).setUp()
         self.doc_handler_mock = mock.Mock()
@@ -241,23 +239,20 @@ class TestProviderHelpCommand(TestHelpCommandBase):
         self.usage = None
 
         # Create a temporary index file for ``aws help [command]`` to use.
-        self.tags_dict = {'topic-name-1': {}, 'topic-name-2': {}}
+        self.tags_dict = {
+            'topic-name-1': {},
+            'topic-name-2': {}
+        }
         json_index = self.file_creator.create_file('index.json', '')
         with open(json_index, 'w') as f:
             json.dump(self.tags_dict, f, indent=4, sort_keys=True)
         self.json_patch = mock.patch(
-            'awscli.topictags.TopicTagDB.index_file', json_index
-        )
+            'awscli.topictags.TopicTagDB.index_file', json_index)
         self.json_patch.start()
 
-        self.cmd = ProviderHelpCommand(
-            self.session,
-            self.command_table,
-            self.arg_table,
-            self.description,
-            self.synopsis,
-            self.usage,
-        )
+        self.cmd = ProviderHelpCommand(self.session, self.command_table,
+                                       self.arg_table, self.description,
+                                       self.synopsis, self.usage)
 
     def tearDown(self):
         self.json_patch.stop()
@@ -277,16 +272,15 @@ class TestProviderHelpCommand(TestHelpCommandBase):
 
         # Ensure the topics are there as well
         self.assertIn('topic-name-1', subcommand_table)
-        self.assertIsInstance(
-            subcommand_table['topic-name-1'], TopicHelpCommand
-        )
+        self.assertIsInstance(subcommand_table['topic-name-1'],
+                              TopicHelpCommand)
         self.assertEqual(subcommand_table['topic-name-1'].name, 'topic-name-1')
 
         self.assertIn('topic-name-2', subcommand_table)
-        self.assertIsInstance(
-            subcommand_table['topic-name-2'], TopicHelpCommand
-        )
-        self.assertEqual(subcommand_table['topic-name-2'].name, 'topic-name-2')
+        self.assertIsInstance(subcommand_table['topic-name-2'],
+                              TopicHelpCommand)
+        self.assertEqual(subcommand_table['topic-name-2'].name,
+                         'topic-name-2')
 
 
 class TestTopicListerCommand(TestHelpCommandBase):
